# Linux CLI Text Processing Exercises

This TUI application includes 60+ questions to test your CLI text processing skills.

> **Note:** This application is intended for exercises based on Linux CLI tools. You might still be able to solve the exercises on other platforms, but I'm not sure if it works.

# Screenshot

![Sample question](https://raw.githubusercontent.com/learnbyexample/TUI-apps/main/CLI-Exercises/cli_exercises.png)

# Guide

See [app_guide.md](https://github.com/learnbyexample/TUI-apps/blob/main/CLI-Exercises/app_guide.md)

# Video demo

You can view a video demo here: [https://youtu.be/0ggfQzXeYJg](https://youtu.be/0ggfQzXeYJg)

# License

Code snippets are licensed under [MIT LICENSE](https://github.com/learnbyexample/TUI-apps/blob/main/LICENSE)

Exercise questions and associated files (like `questions.json`) are licensed under [Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License](https://creativecommons.org/licenses/by-nc-sa/4.0/)

